import request from "@/utils/request";
import { AxiosPromise } from "axios";
import { RoleQuery, RolePageResult, RoleForm } from "./types";

/**
 * 获取角色分页数据
 *
 * @param queryParams
 */
export function getRolePage(
  queryParams?: RoleQuery
): AxiosPromise<RolePageResult> {
  return request({
    url: "/system/role/list",
    method: "get",
    params: queryParams,
  });
}
/**
 * 获取角色下拉数据
 *
 * @param queryParams
 */
export function getRoleOptions(
  queryParams?: RoleQuery
): AxiosPromise<OptionType[]> {
  return request({
    url: "system/role/listAll",
    method: "get",
    params: queryParams,
  });
}

/** 角色数据权限*/
export function dataScope(data: any) {
  return request({
    url: "/system/role/dataScope",
    method: "put",
    data,
    headers: {},
  });
}
/**
 * 获取角色的菜单ID集合
 *
 * @param queryParams
 */
export function getRoleMenuIds(roleId: number): AxiosPromise<number[]> {
  return request({
    url: "/api/v1/roles/" + roleId + "/menuIds",
    method: "get",
  });
}
/**
 * 查询菜单下拉树结构
 *
 */
export function treeSelect() {
  return request({
    url: "/system/menu/treeSelect",
    method: "get",
  });
}

/**
 * 用户状态修改
 *
 */
export function changeRoleStatus(businessId: number, flag: string) {
  const data = {
    businessId,
    flag,
  };
  return request({
    url: "/system/role/changeStatus",
    method: "put",
    params: data,
  });
}
/**
 * 分配菜单权限给角色
 *
 * @param queryParams
 */
export function updateRoleMenus(
  roleId: number,
  data: number[]
): AxiosPromise<any> {
  return request({
    url: "/api/v1/roles/" + roleId + "/menus",
    method: "put",
    data: data,
  });
}

/**
 * 获取角色详情
 *
 * @param id
 */
export function getRoleForm(id: number): AxiosPromise<RoleForm> {
  return request({
    url: "/system/role/detail/" + id,
    method: "get",
  });
}
/**
 * 根据角色ID查询菜单下拉树结构
 *
 * @param id
 */
export function roleMenuTreeSelect(roleId: any) {
  return request({
    url: "/system/menu/roleMenuTreeSelect/" + roleId,
    method: "get",
  });
}
/** 根据角色ID查询菜单下拉树结构 无按钮 */
export function roleMenuTreeSelectMC(roleId: any) {
  return request({
    url: "/system/menu/treeSelectMC/" + roleId,
    method: "get",
  });
}
/** 根据角色ID查询部门树结构*/
export function roleDeptTreeSelect(roleId: any, menuId: any) {
  return request({
    url: "/system/dept/roleDeptTreeSelect/" + roleId + "/" + menuId,
    method: "get",
  });
}
/**
 * 查询角色详细
 *
 */
export function getRole(businessId: any) {
  return request({
    url: "/system/role/detail/" + businessId,
    method: "get",
  });
}
/**
 * 添加角色
 *
 * @param data
 */
export function addRole(data: RoleForm) {
  return request({
    url: "/system/role/add",
    method: "post",
    data: data,
  });
}

/**
 * 更新角色
 *
 * @param id
 * @param data
 */
export function updateRole(id: number, data: RoleForm) {
  return request({
    url: "/system/role/update/" + id,
    method: "put",
    data: data,
  });
}

/**
 * 批量删除角色，多个以英文逗号(,)分割
 *
 * @param ids
 */
export function deleteRoles(roleId: any) {
  return request({
    url: "/system/role/deleteLogical/" + roleId,
    method: "delete",
  });
}
